

module app.contactTypes.services {

    import IHttpResult = app.core.services.http.IHttpResult;
    import IContactType = app.contactTypes.models.IContactType;

    export interface IContactsTypeService {
        getContactTypes: (callback: (result: IContactType[]) => void) => void;
        getContactType: (id:number, callback: (result: IContactType) => void) => void;
        deleteContactType: (contactType: IContactType, callback: (result: boolean) => void) => void;
        saveContactType: (contactType: IContactType, callback: (result: IContactType) => void) => void;
    }

    class ContactsTypeService implements IContactsTypeService {
        getContactTypes: (callback: (result: IContactType[]) => void) => void;
        getContactType: (id: number, callback: (result: IContactType) => void) => void;
        deleteContactType: (contactType: IContactType, callback: (result: boolean) => void) => void;
        saveContactType: (contactType: IContactType, callback: (result: IContactType) => void) => void;

        constructor(http: app.core.services.http.IHttp, utilities: app.core.services.IUtilities) {

            this.getContactTypes = function (callback: (result: IContactType[]) => void) {
                return http.get("/ContactTypes/Get", (result: IHttpResult<IContactType[]>) => {
                    if (result.Success) {
                        callback(result.Result);
                    }
                }, true);
            };

            this.deleteContactType = function (contactType: IContactType, callback: (result: boolean) => void) {
                return http.post("/ContactTypes/Delete", contactType, (result: IHttpResult<IContactType>) => {
                    callback(result.Success);
                }, true);
            };

            this.getContactType = function (id: number, callback: (result: IContactType) => void) {
                return http.get("/ContactTypes/GetById", (result: IHttpResult<IContactType>) => {
                    if (result.Success) {
                        callback(result.Result);
                    }
                }, true, { contactTypeId: id });
            };

            this.saveContactType = function (contactType: IContactType, callback: (result: IContactType) => void) {
                return http.post("/ContactTypes/Save", contactType, (result: IHttpResult<IContactType>) => {
                    if (result.Result) {
                        callback(result.Result);
                    }
                }, true);
            };
        }
    }

    angular.module("app.contactTypes.services", [])
        .factory("contactsTypeService", ["http", "utilities", "globalsService",
            function (http: app.core.services.http.IHttp, utilities: app.core.services.IUtilities) {
                return new ContactsTypeService(http, utilities);
            }]);
}