
module app.contacts {

    import IUtilities = app.core.services.IUtilities;
    import IHttp = app.core.services.http.IHttp;
    import IHttpResult = app.core.services.http.IHttpResult;
    import IContactsService = app.contacts.services.IContactsService;
    import IContactInfo = app.contacts.models.IContactInfo;
    import IPagedResult = app.core.services.http.IPagedResult;

    interface IContactScope extends ng.IScope {
        contacts: IContactInfo[];
        editContact: (contact: IContactInfo) => void;
        deleteContact: (contact: IContactInfo) => void;
        add: () => void;
        pageCount: number;
        pageSize: number;
        gotoPage: (pageNumber: number) => void;
        totalFound: number;
        name: string;
        search: (pageNumber: number, pageSize: number, name: string, eventToRaise: string) => void;
        performSearch: () => void;
        currentPage: number;
    }

    class ContactsController extends app.core.controllers.CoreController {

        constructor(
            private utilities: IUtilities,
            private $scope: IContactScope,
            $location: ng.ILocationService,
            contactsService: IContactsService) {
            super($scope);
            $scope.pageSize = 10;
            $scope.pageCount = 0;
            $scope.currentPage = 1;
            $scope.search = (pageNumber: number, pageSize: number, name: string, eventToRaise: string) => {
                contactsService.getContacts(
                    { PageNumber: pageNumber, PageSize: pageSize, Name: name },
                    (result: IPagedResult<IContactInfo>) => {
                        $scope.contacts = result.Result;
                        $scope.pageCount = result.TotalPages;
                        $scope.totalFound = result.TotalRows;
                        $scope.currentPage = pageNumber;
                        $scope.$broadcast(eventToRaise);
                    });
            };

            $scope.search(1, $scope.pageSize, $scope.name, "searchCompleted");

            $scope.performSearch = () => {
                $scope.search(1, $scope.pageSize, $scope.name, "searchCompleted");
            };
            $scope.gotoPage = function (pageNumber: number) {
                $scope.search(pageNumber, $scope.pageSize, $scope.name, "pageLoadCompleted");
            };

            $scope.editContact = (contact: app.contacts.models.IContactInfo) => {
                $location.path("/contact/edit/" + contact.ContactId);
            };

            $scope.add = () => {
                $location.path("/contact/edit/add");
            };

            var deleted = function (result: boolean) {
                if (result) {
                    $scope.search($scope.currentPage, $scope.pageSize, $scope.name, "searchCompleted");
                }
            };

            var deleteContact = (contact: IContactInfo) => {
                contactsService.deleteContact(contact, deleted);
            };

            $scope.deleteContact = (contact: app.contacts.models.IContactInfo) => {
                var buttons: app.core.services.IButtonForMessage[] = [
                    {
                        mehtod: () => {
                            deleteContact(contact);
                        },
                        label: "Delete"
                    },
                    {
                        label: "Cancel"
                    }
                ];
                utilities.showMessage("Delete " + contact.LastName + ", " + contact.FirstName + "?", false, buttons);
            };
        }

    }

    angular.module("app.contacts.contactsController", ["app.core.services.utilities", "app.contacts.services"])
        .controller("app.contacts.contactsController", ["utilities", "$scope", "$location", "contactsService",
            function (utilities: IUtilities, $scope: IContactScope, $location: ng.ILocationService, contactsService: IContactsService) {
                return new ContactsController(utilities, $scope, $location, contactsService);
            }]);
}